package com.sf.index.mapper;

import java.util.List;
import com.sf.index.domain.ApplyListInfo;

/**
 * 应用列Mapper接口
 * 
 * @author ztzh
 * @date 2024-04-11
 */
public interface ApplyListInfoMapper 
{
    /**
     * 查询应用列
     * 
     * @param id 应用列主键
     * @return 应用列
     */
    public ApplyListInfo selectApplyListInfoById(Long id);

    /**
     * 查询应用列列表
     * 
     * @param applyListInfo 应用列
     * @return 应用列集合
     */
    public List<ApplyListInfo> selectApplyListInfoList(ApplyListInfo applyListInfo);

    /**
     * 新增应用列
     * 
     * @param applyListInfo 应用列
     * @return 结果
     */
    public int insertApplyListInfo(ApplyListInfo applyListInfo);

    /**
     * 修改应用列
     * 
     * @param applyListInfo 应用列
     * @return 结果
     */
    public int updateApplyListInfo(ApplyListInfo applyListInfo);

    /**
     * 删除应用列
     * 
     * @param id 应用列主键
     * @return 结果
     */
    public int deleteApplyListInfoById(Long id);

    /**
     * 批量删除应用列
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteApplyListInfoByIds(Long[] ids);
}
